# Frequently asked questions

Frequently asked questions about the usage and design of Bionty.

---

**NOTE**

This section will be populated soon.

---

## What is the Entity table model?

## How do I see which ontologies are available?

## How do I add new ontologies?

## How do I add new entities?

## How were the underlying assets curated?

See [bionty-assets](https://lamin.ai/docs/bionty-assets) for the curation of underlying assets.
